@@ -8,13 +8,13 @@
  ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  ## GNU General Public License for more details.
  ##
-from PyQt4 import QtCore, QtGui
+from PyQt4 import QtCore
+from PyQt4.QtGui import QApplication
 from ui.mainWindow import MainWindow
 
-
 if __name__ == "__main__":
     import sys
-    app = QtGui.QApplication(sys.argv)
+    app = QApplication(sys.argv)
     ui = MainWindow()
     ui.showFullScreen() 
     ui.setWindowTitle('Ansel-A:Digital Darkroom')
